Rdocumentation
powered by
Learn R Programming
wrapr (version 1.8.8)
PartialFunction-class: Function with partial arguments as a new single argument function.
Description
Function with partial arguments as a new single argument function.
Arguments