Learn R Programming

wrapr (version 1.8.8)

apply_left.UnaryFn: Apply right wrapped function to argument on left.

Description

Apply right wrapped function to argument on left.

Usage

# S3 method for UnaryFn
apply_left(pipe_left_arg, pipe_right_arg,
  pipe_environment, left_arg_name, pipe_string, right_arg_name)

Arguments

pipe_left_arg

left argument should be a class derived from UnaryFn.

pipe_right_arg

substitute(pipe_right_arg) argument, should evaluate to a class derived from UnaryFn.

pipe_environment

environment to evaluate in

left_arg_name

name, if not NULL name of left argument.

pipe_string

character, name of pipe operator.

right_arg_name

name, if not NULL name of right argument.

Value

result