Triggered if right hand side of pipe stage was a name that does not resolve to a function. For formal documentation please see https://github.com/WinVector/wrapr/blob/master/extras/wrapr_pipe.pdf.
# S3 method for locum
apply_right(
pipe_left_arg,
pipe_right_arg,
pipe_environment,
left_arg_name,
pipe_string,
right_arg_name
)left argument
right argument
environment to evaluate in
name, if not NULL name of left argument.
character, name of pipe operator.
name, if not NULL name of right argument.
result