Apply right wrapped function to argument on left.
# S3 method for UnaryFn
apply_left(pipe_left_arg, pipe_right_arg,
pipe_environment, left_arg_name, pipe_string, right_arg_name)left argument should be a class derived from UnaryFn.
substitute(pipe_right_arg) argument, should evaluate to a class derived from UnaryFn.
environment to evaluate in
name, if not NULL name of left argument.
character, name of pipe operator.
name, if not NULL name of right argument.
result